django-andablog
===============

|Build Status|

(Just) A blog app for Django
~~~~~~~~~~~~~~~~~~~~~~~~~~~~

This app is only intended to be embedded within an existing Django site.
Full
`documentation <http://django-andablog.readthedocs.org/en/latest/>`__ is
available but here are the highlights.

-  `Features <http://django-andablog.readthedocs.org/en/latest/#features>`__
-  `Installation &
   Usage <http://django-andablog.readthedocs.org/en/latest/install-usage.html>`__
-  `Demo
   Site <http://django-andablog.readthedocs.org/en/latest/demo-site.html>`__

.. |Build Status| image:: https://travis-ci.org/WimpyAnalytics/django-andablog.svg?branch=master
   :target: https://travis-ci.org/WimpyAnalytics/django-andablog
